@@ -11,8 +11,6 @@ from pathlib import Path
 from typing import Set, Type, List, Tuple, Optional, Iterable, Generator
 
 from colorama import Fore
-from packaging.version import LegacyVersion
-from packaging.version import parse as parse_version
 
 from bauh.api.abstract.context import ApplicationContext
 from bauh.api.abstract.controller import SoftwareManager, SearchResult, UpgradeRequirements, UpgradeRequirement, \
@@ -28,6 +26,7 @@ from bauh.commons import resource
 from bauh.commons.boot import CreateConfigFile
 from bauh.commons.html import bold
 from bauh.commons.system import SystemProcess, new_subprocess, ProcessHandler, SimpleProcess
+from bauh.commons.version_util import normalize_version
 from bauh.gems.appimage import query, INSTALLATION_DIR, APPIMAGE_SHARED_DIR, ROOT_DIR, \
     APPIMAGE_CONFIG_DIR, UPDATES_IGNORED_FILE, util, get_default_manual_installation_file_dir, DATABASE_APPS_FILE, \
     DATABASE_RELEASES_FILE, APPIMAGE_CACHE_DIR, get_icon_path, DOWNLOAD_DIR
@@ -177,7 +176,7 @@ class AppImageManager(SoftwareManager, SettingsController):
         if os.path.exists(db_path):
             try:
                 return sqlite3.connect(db_path)
-            except:
+            except Exception:
                 self.logger.error(f"Could not connect to database file '{db_path}'")
                 traceback.print_exc()
         else:
@@ -207,13 +206,13 @@ class AppImageManager(SoftwareManager, SettingsController):
                 not_installed.append(app)
                 found_map[self._gen_app_key(app)] = {'app': app, 'idx': idx}
                 idx += 1
-        except:
+        except Exception:
             self.logger.error("An exception happened while querying the 'apps' database")
             traceback.print_exc()
 
         try:
             installed = self.read_installed(connection=apps_conn, disk_loader=disk_loader, limit=limit, only_apps=False, pkg_types=None, internet_available=True).installed
-        except:
+        except Exception:
             installed = None
 
         installed_found = []
@@ -241,7 +240,7 @@ class AppImageManager(SoftwareManager, SettingsController):
                     installed_found.append(appim)
         try:
             apps_conn.close()
-        except:
+        except Exception:
             self.logger.error(f"An exception happened when trying to close the connection to database file '{DATABASE_APPS_FILE}'")
             traceback.print_exc()
 
@@ -286,18 +285,21 @@ class AppImageManager(SoftwareManager, SettingsController):
                                             elif continuous_update and not continuous_version:
                                                 app.update = False
                                             else:
-                                                try:
-                                                    app.update = parse_version(tup[2]) > parse_version(app.version) if tup[2] else False
-                                                except:
-                                                    app.update = False
-                                                    traceback.print_exc()
+                                                if tup[2]:
+                                                    try:
+                                                        latest_version = normalize_version(tup[2])
+                                                        installed_version = normalize_version(app.version)
+                                                        app.update = latest_version > installed_version
+                                                    except Exception:
+                                                        app.update = False
+                                                        traceback.print_exc()
 
                                         if app.update:
                                             app.latest_version = tup[2]
                                             app.url_download_latest_version = tup[3]
 
                                         break
-                        except:
+                        except Exception:
                             self.logger.error(f"An exception happened while querying the database file '{DATABASE_APPS_FILE}'")
                             traceback.print_exc()
                         finally:
@@ -417,7 +419,7 @@ class AppImageManager(SoftwareManager, SettingsController):
             try:
                 os.remove(pkg.symlink)
                 self.logger.info(f"symlink '{pkg.symlink}' successfully removed")
-            except:
+            except Exception:
                 msg = f"could not remove symlink '{pkg.symlink}'"
                 self.logger.error(msg)
 
@@ -490,7 +492,7 @@ class AppImageManager(SoftwareManager, SettingsController):
             if not app_tuple:
                 self.logger.warning(f"Could not retrieve {pkg} from the database '{DATABASE_APPS_FILE}'")
                 return res
-        except:
+        except Exception:
             self.logger.error(f"An exception happened while querying the database file '{DATABASE_APPS_FILE}'")
             traceback.print_exc()
             app_con.close()
@@ -509,20 +511,19 @@ class AppImageManager(SoftwareManager, SettingsController):
             releases = cursor.execute(query.FIND_RELEASES_BY_APP_ID.format(app_tuple[0]))
 
             if releases:
-                treated_releases = [(LegacyVersion(r[0]), *r[1:]) for r in releases]
+                treated_releases = [(normalize_version(r[0]), r[0], *r[1:]) for r in releases]
                 treated_releases.sort(key=self._sort_release, reverse=True)
 
                 for idx, tup in enumerate(treated_releases):
-                    ver = str(tup[0])
-                    history.append({'0_version': ver,
-                                    '1_published_at': datetime.strptime(tup[2], '%Y-%m-%dT%H:%M:%SZ') if tup[
-                                        2] else '', '2_url_download': tup[1]})
+                    ver = tup[1]
+                    date_ = datetime.strptime(tup[3], '%Y-%m-%dT%H:%M:%SZ') if tup[3] else ''
+                    history.append({'0_version': ver, '1_published_at': date_, '2_url_download': tup[2]})
 
                     if res.pkg_status_idx == -1 and pkg.version == ver:
                         res.pkg_status_idx = idx
 
                 return res
-        except:
+        except Exception:
             self.logger.error(f"An exception happened while querying the database file '{DATABASE_RELEASES_FILE}'")
             traceback.print_exc()
         finally:
@@ -600,7 +601,7 @@ class AppImageManager(SoftwareManager, SettingsController):
 
             try:
                 moved, output = handler.handle_simple(SimpleProcess(['mv', pkg.local_file_path, install_file_path]))
-            except:
+            except Exception:
                 output = ''
                 self.logger.error(f"Could not rename file '{pkg.local_file_path}' as '{install_file_path}'")
                 moved = False
@@ -649,7 +650,7 @@ class AppImageManager(SoftwareManager, SettingsController):
                                          type_=MessageType.ERROR)
                     handler.handle(SystemProcess(new_subprocess(['rm', '-rf', out_dir])))
                     return TransactionResult.fail()
-            except:
+            except Exception:
                 watcher.show_message(title=self.i18n['error'],
                                      body=traceback.format_exc(),
                                      type_=MessageType.ERROR)
@@ -691,7 +692,7 @@ class AppImageManager(SoftwareManager, SettingsController):
 
                 try:
                     shutil.rmtree(extracted_folder)
-                except:
+                except Exception:
                     traceback.print_exc()
 
                 SymlinksVerifier.create_symlink(app=pkg, file_path=install_file_path, logger=self.logger,
@@ -814,7 +815,7 @@ class AppImageManager(SoftwareManager, SettingsController):
 
                     self.logger.info(f"Mapped {len(res)} AppImage suggestions")
                     return res
-                except:
+                except Exception:
                     traceback.print_exc()
                 finally:
                     connection.close()
@@ -849,7 +850,7 @@ class AppImageManager(SoftwareManager, SettingsController):
 
                 if logs:
                     print(f'{Fore.YELLOW}[bauh][appimage] {f} deleted{Fore.RESET}')
-            except:
+            except Exception:
                 if logs:
                     print(f'{Fore.RED}[bauh][appimage] An exception has happened when deleting {f}{Fore.RESET}')
                     traceback.print_exc()
@@ -884,7 +885,7 @@ class AppImageManager(SoftwareManager, SettingsController):
         try:
             self.configman.save_config(config_)
             return True, None
-        except:
+        except Exception:
             return False, [traceback.format_exc()]
 
     def gen_custom_actions(self) -> Generator[CustomSoftwareAction, None, None]:
