@@ -7,8 +7,6 @@ from pathlib import Path
 from threading import Thread
 from typing import List, Set, Type, Tuple, Optional, Generator, Dict
 
-from packaging.version import Version
-
 from bauh.api import user
 from bauh.api.abstract.controller import SearchResult, SoftwareManager, ApplicationContext, UpgradeRequirements, \
     UpgradeRequirement, TransactionResult, SoftwareAction, SettingsView, SettingsController
@@ -123,7 +121,7 @@ class FlatpakManager(SoftwareManager, SettingsController):
         res.total = len(res.installed) + len(res.new)
         return res
 
-    def _add_updates(self, version: Version, output: list):
+    def _add_updates(self, version: Tuple[str, ...], output: list):
         output.append(flatpak.list_updates_as_str(version))
 
     def _fill_required_runtimes(self, installation: str, output: List[Tuple[str, str]]):
@@ -317,7 +315,7 @@ class FlatpakManager(SoftwareManager, SettingsController):
                 if not res:
                     self.logger.warning("Could not upgrade '{}'".format(req.pkg.id))
                     return False
-            except:
+            except Exception:
                 watcher.change_substatus('')
                 self.logger.error("An error occurred while upgrading '{}'".format(req.pkg.id))
                 traceback.print_exc()
@@ -394,7 +392,7 @@ class FlatpakManager(SoftwareManager, SettingsController):
                     if res.get(to_date):
                         try:
                             res[to_date] = datetime.strptime(res[to_date], DATE_FORMAT)
-                        except:
+                        except Exception:
                             self.context.logger.error('Could not convert date string {} as {}'.format(res[to_date], DATE_FORMAT))
                             pass
 
@@ -437,7 +435,7 @@ class FlatpakManager(SoftwareManager, SettingsController):
             watcher.print('Creating dir {}'.format(EXPORTS_PATH))
             try:
                 Path(EXPORTS_PATH).mkdir(parents=True, exist_ok=True)
-            except:
+            except Exception:
                 watcher.print('Error while creating the directory {}'.format(EXPORTS_PATH))
                 return False
 
@@ -530,7 +528,7 @@ class FlatpakManager(SoftwareManager, SettingsController):
                 if fields:
                     pkg.ref = fields[0]
                     pkg.branch = fields[1]
-            except:
+            except Exception:
                 traceback.print_exc()
 
         if installed:
@@ -603,7 +601,7 @@ class FlatpakManager(SoftwareManager, SettingsController):
         if file:
             return file.text
 
-    def _fill_suggestion(self, appid: str, priority: SuggestionPriority, flatpak_version: Version, remote: str,
+    def _fill_suggestion(self, appid: str, priority: SuggestionPriority, flatpak_version: Tuple[str, ...], remote: str,
                          output: List[PackageSuggestion]):
         app_json = flatpak.search(flatpak_version, appid, remote, app_id=True)
 
@@ -735,7 +733,7 @@ class FlatpakManager(SoftwareManager, SettingsController):
         try:
             self.configman.save_config(flatpak_config)
             return True, None
-        except:
+        except Exception:
             return False, [traceback.format_exc()]
 
     def get_upgrade_requirements(self, pkgs: List[FlatpakApplication], root_password: Optional[str], watcher: ProcessWatcher) -> UpgradeRequirements:
